# Tutorial - User Guide - Intro

## Getting Started

### Installs

```
$ pip install dictdaora
```

### Starts coding


```python
{!./src/index/index_00_basic.py!}
```

```
{!./src/index/index_00_basic.output!}
```
